==> jc-1.4.0.tar.gz: soot/javaToJimple/CastInsertionVisitor.h <==
// public class soot.javaToJimple.CastInsertionVisitor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f8e2af057551681 polyglot_visit_AscriptionVisitor
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 561329c9d2db394d soot_javaToJimple_CastInsertionVisitor

// header file dependencies
// @dep_header polyglot_visit_AscriptionVisitor

#include "polyglot/visit/AscriptionVisitor.h"

#ifndef _JC_soot_javaToJimple_CastInsertionVisitor_H_
#define _JC_soot_javaToJimple_CastInsertionVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_refs	_jc_soot_javaToJimple_CastInsertionVisitor$sub_refs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs	_jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$refs	_jc_soot_javaToJimple_CastInsertionVisitor$refs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$nonrefs	_jc_soot_javaToJimple_CastInsertionVisitor$nonrefs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$object	_jc_soot_javaToJimple_CastInsertionVisitor$object;

typedef const struct _jc_soot_javaToJimple_CastInsertionVisitor$vmethods	_jc_soot_javaToJimple_CastInsertionVisitor$vmethods;
typedef const struct _jc_soot_javaToJimple_CastInsertionVisitor$vtable	_jc_soot_javaToJimple_CastInsertionVisitor$vtable;
typedef const struct _jc_soot_javaToJimple_CastInsertionVisitor$vtype	_jc_soot_javaToJimple_CastInsertionVisitor$vtype;

// Constructors
extern void _jc_soot_javaToJimple_CastInsertionVisitor$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_CastInsertionVisitor$method$ascribe$51a47bc56f6458ea(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_javaToJimple_CastInsertionVisitor$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_CastInsertionVisitor$method_info$ascribe$51a47bc56f6458ea;
extern _jc_method _jc_soot_javaToJimple_CastInsertionVisitor$method_info$leaveCall$9236e830bcef4b36;

// Virtual methods structure
struct _jc_soot_javaToJimple_CastInsertionVisitor$vmethods {
	struct _jc_object	*(*ascribe$51a47bc56f6458ea)(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_CastInsertionVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_AscriptionVisitor$vmethods	polyglot_visit_AscriptionVisitor;
	_jc_soot_javaToJimple_CastInsertionVisitor$vmethods	soot_javaToJimple_CastInsertionVisitor;
};

// Vtype
struct _jc_soot_javaToJimple_CastInsertionVisitor$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_CastInsertionVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_CastInsertionVisitor$refs {
    _jc_soot_javaToJimple_CastInsertionVisitor$sub_refs	soot_javaToJimple_CastInsertionVisitor;
    _jc_polyglot_visit_AscriptionVisitor$sub_refs	polyglot_visit_AscriptionVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_CastInsertionVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs	polyglot_visit_AscriptionVisitor;
    _jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs	soot_javaToJimple_CastInsertionVisitor;
};

// Object instance structure
struct _jc_soot_javaToJimple_CastInsertionVisitor$object {
	_jc_soot_javaToJimple_CastInsertionVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_CastInsertionVisitor$vtype	*vtype;
	_jc_soot_javaToJimple_CastInsertionVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_CastInsertionVisitor$vtype _jc_soot_javaToJimple_CastInsertionVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_CastInsertionVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_CastInsertionVisitor$class_object;

#endif	/* _JC_soot_javaToJimple_CastInsertionVisitor_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/CastInsertionVisitor.h <==
// public class soot.javaToJimple.CastInsertionVisitor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f8e2af057551681 polyglot_visit_AscriptionVisitor
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 561329c9d2db394d soot_javaToJimple_CastInsertionVisitor

// header file dependencies
// @dep_header polyglot_visit_AscriptionVisitor

#include "polyglot/visit/AscriptionVisitor.h"

#ifndef _JC_soot_javaToJimple_CastInsertionVisitor_H_
#define _JC_soot_javaToJimple_CastInsertionVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_refs	_jc_soot_javaToJimple_CastInsertionVisitor$sub_refs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs	_jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$refs	_jc_soot_javaToJimple_CastInsertionVisitor$refs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$nonrefs	_jc_soot_javaToJimple_CastInsertionVisitor$nonrefs;
typedef struct _jc_soot_javaToJimple_CastInsertionVisitor$object	_jc_soot_javaToJimple_CastInsertionVisitor$object;

typedef const struct _jc_soot_javaToJimple_CastInsertionVisitor$vmethods	_jc_soot_javaToJimple_CastInsertionVisitor$vmethods;
typedef const struct _jc_soot_javaToJimple_CastInsertionVisitor$vtable	_jc_soot_javaToJimple_CastInsertionVisitor$vtable;
typedef const struct _jc_soot_javaToJimple_CastInsertionVisitor$vtype	_jc_soot_javaToJimple_CastInsertionVisitor$vtype;

// Constructors
extern void _jc_soot_javaToJimple_CastInsertionVisitor$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_CastInsertionVisitor$method$ascribe$51a47bc56f6458ea(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_CastInsertionVisitor$method$leaveCall$9236e830bcef4b36(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_CastInsertionVisitor$method_info$ascribe$51a47bc56f6458ea;
extern _jc_method _jc_soot_javaToJimple_CastInsertionVisitor$method_info$leaveCall$9236e830bcef4b36;

// Virtual methods structure
struct _jc_soot_javaToJimple_CastInsertionVisitor$vmethods {
	struct _jc_object	*(*ascribe$51a47bc56f6458ea)(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leaveCall$9236e830bcef4b36)(_jc_env *, struct _jc_soot_javaToJimple_CastInsertionVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_CastInsertionVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_AscriptionVisitor$vmethods	polyglot_visit_AscriptionVisitor;
	_jc_soot_javaToJimple_CastInsertionVisitor$vmethods	soot_javaToJimple_CastInsertionVisitor;
};

// Vtype
struct _jc_soot_javaToJimple_CastInsertionVisitor$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_CastInsertionVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_CastInsertionVisitor$refs {
    _jc_soot_javaToJimple_CastInsertionVisitor$sub_refs	soot_javaToJimple_CastInsertionVisitor;
    _jc_polyglot_visit_AscriptionVisitor$sub_refs	polyglot_visit_AscriptionVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_CastInsertionVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_AscriptionVisitor$sub_nonrefs	polyglot_visit_AscriptionVisitor;
    _jc_soot_javaToJimple_CastInsertionVisitor$sub_nonrefs	soot_javaToJimple_CastInsertionVisitor;
};

// Object instance structure
struct _jc_soot_javaToJimple_CastInsertionVisitor$object {
	_jc_soot_javaToJimple_CastInsertionVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_CastInsertionVisitor$vtype	*vtype;
	_jc_soot_javaToJimple_CastInsertionVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_CastInsertionVisitor$vtype _jc_soot_javaToJimple_CastInsertionVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_CastInsertionVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_CastInsertionVisitor$class_object;

#endif	/* _JC_soot_javaToJimple_CastInsertionVisitor_H_ */
